# coding: utf-8
from os.path import dirname
from os.path import isabs
from os.path import join
import re

from pkg_resources import Requirement
from setuptools import find_packages
from setuptools import setup


_COMMENT_RE = re.compile(r'(^|\s)+#.*$')


def _get_requirements(file_path):
    if isabs(file_path):
        file_path = join(dirname(__file__), file_path)

    with open(file_path, 'r') as file:
        for line in file:
            line = _COMMENT_RE.sub('', line)
            line = line.strip()
            if line.startswith('-r '):
                for req in _get_requirements(
                    join(dirname(file_path), line[3:])
                ):
                    yield req
            elif line:
                req = Requirement(line)
                req_str = req.name + str(req.specifier)
                if req.marker:
                    req_str += '; ' + str(req.marker)
                yield req_str


def main():
    setup(
        name='m3-auth',
        author="BARS Group",
        author_email='education_dev@bars-open.ru',
        url='https://stash.bars-open.ru/projects/EDUBASE/repos/auth',
        classifiers=(
            'Intended Audience :: Developers',
            'Environment :: Web Environment',
            'Natural Language :: Russian',
            'Natural Language :: English',
            'Operating System :: OS Independent',
            'Development Status :: 5 Production/Stable',
            'Programming Language :: Python',
            'Programming Language :: Python :: 2.7',
            'Programming Language :: Python :: 3.6',
            'Framework :: Django :: 1.4',
            'Framework :: Django :: 1.5',
            'Framework :: Django :: 1.6',
            'Framework :: Django :: 1.7',
            'Framework :: Django :: 1.8',
            'Framework :: Django :: 1.9',
            'Framework :: Django :: 1.10',
            'Framework :: Django :: 1.11',
            'Framework :: Django :: 2.0',
            'Framework :: Django :: 2.1',
        ),
        package_dir={'': 'src'},
        packages=find_packages('src'),
        include_package_data=True,
        dependency_links=('http://pypi.bars-open.ru/simple/m3-builder',),
        setup_requires=('m3-builder>=1.1',),
        install_requires=_get_requirements('requirements/prod.txt'),
        set_build_info=join(dirname(__file__)),
        extras_require={
            'oauth': (
                'oauthlib>=2,<3',
                'requests-oauthlib<1',
            ),
            'saml': (
                'python3-saml>=1.4,<1.5',
            ),
            'ldap': (
                'django-auth-ldap>=1.7,<1.8',
            )
        },
    )


if __name__ == '__main__':
    main()
