# coding: utf-8


from __future__ import absolute_import
from __future__ import unicode_literals

import ldap

from django.utils.encoding import force_text
from django_auth_ldap.config import LDAPSearch
from ldap.controls import SimplePagedResultsControl


class LDAPPageSearch(LDAPSearch):
    """Реализует возможность постраничного поиска в AD."""

    def __init__(
            self, base_dn, scope, filterstr='(objectClass=*)',
            attrlist=None, page_size=500
    ):
        super(LDAPPageSearch, self).__init__(
            base_dn, scope, filterstr, attrlist
        )
        self.page_size = page_size

    def execute(self, connection, filterargs=(), escape=True):
        """Поиск пользователя по заданным атрибутам."""

        # Необходимо для того чтобы поиск осущ. с заданными в настройках
        # логином/паролем. По умолчанию поиск в MS AD осущ.
        # под анонимным пользователем
        connection.set_option(ldap.OPT_REFERRALS, 0)

        filterstr = self.filterstr % filterargs
        resp_ctrl_classes = {
            SimplePagedResultsControl.controlType: SimplePagedResultsControl,
        }

        msg_id = self._get_search_id(connection, filterstr)
        while True:
            rtype, rdata, rmsgid, server_ctrls = connection.result3(
                msg_id,
                resp_ctrl_classes=resp_ctrl_classes
            )
            page_crtl = [
                c
                for c in server_ctrls
                if c.controlType == SimplePagedResultsControl.controlType
            ]
            if rdata:
                return self._process_results(rdata)
            elif page_crtl and page_crtl[0].cookie:
                    msg_id = self._get_search_id(
                        connection, filterstr, page_crtl[0].cookie
                    )
            else:
                return None

    def _get_search_id(self, connection, filterstr, cookie=''):
        """Получение поискового идентификатор.

        Выполняет асинхроный поиск и возвращает id выполненого запроса для
        дальнейшго получения результатов запроса. При постраничном поиске
        для выполнения повторных запросов необходимо указать cookie которое
        возвращает функция result3.
        """
        server_ctrl = SimplePagedResultsControl(
            True, size=self.page_size, cookie=cookie
        )

        msg_id = connection.search_ext(
            force_text(self.base_dn),
            self.scope,
            filterstr=filterstr,
            serverctrls=[server_ctrl],
        )

        return msg_id
