# coding: utf-8

from __future__ import absolute_import
from __future__ import unicode_literals

from abc import ABCMeta
from abc import abstractmethod

import six


class BaseOAuthServerApi(six.with_metaclass(ABCMeta)):

    """
    Базовый класс для работы с API сервера авторизации.
    Потомки данного класса должны реализовать метод get_person_info который
    в свою очередь должен запрашивать и возвращать данные о пользователе.

    :ivar config: Объект с конфигурациями.
    :type config: auth.config.Config
    """

    def __init__(self, config):
        self.config = config

    @abstractmethod
    def get_person_info(self, request, client):
        """Метод должен запрашивать данные о пользователе и возвращать словарь
        с его информацией.

        :param request: Запрос.
        :type request: django.http.HttpRequest

        :param client: Объект класса WebApplicationClient.
        :type client: oauthlib.oauth2.WebApplicationClient

        :return: Информация о пользователе с сервер авторизации.
        :rtype: dict
        """
